If we return regular Message objects, python will try to destroy them,
and the underlying notmuch object, causing e.g. the crash [1].

[1]: id:87sfu6utxg....@tethera.net
---
 bindings/python-cffi/notmuch2/_message.py | 4 ++--
 test/T392-python-cffi-notmuch.sh          | 2 --
 2 files changed, 2 insertions(+), 4 deletions(-)

diff --git a/test/T392-python-cffi-notmuch.sh b/test/T392-python-cffi-notmuch.sh
index 50012c55..15c8fc6b 100755
--- a/test/T392-python-cffi-notmuch.sh
+++ b/test/T392-python-cffi-notmuch.sh
@@ -24,13 +24,11 @@ show_msgs(thread, 0)
 EOF
 
 test_begin_subtest "recursive traversal of replies (no crash)"
-test_subtest_known_broken
 test_python < recurse.py
 error=$?
 test_expect_equal "${error}" 0
 
 test_begin_subtest "recursive traversal of replies (output)"
-test_subtest_known_broken
 test_python < recurse.py
 tail -n 10 < OUTPUT > OUTPUT.sample
 cat <<EOF > EXPECTED
diff --git a/bindings/python-cffi/notmuch2/_message.py 
b/bindings/python-cffi/notmuch2/_message.py
index a460d8c1..aa1cb875 100644
--- a/bindings/python-cffi/notmuch2/_message.py
+++ b/bindings/python-cffi/notmuch2/_message.py
@@ -371,14 +371,14 @@ class Message(base.NotmuchObject):
         This method will only work if the message was created from a
         thread.  Otherwise it will yield no results.
 
         :returns: An iterator yielding :class:`Message` instances.
         :rtype: MessageIter
         """
         # The notmuch_messages_valid call accepts NULL and this will
         # become an empty iterator, raising StopIteration immediately.
         # Hence no return value checking here.
         msgs_p = capi.lib.notmuch_message_get_replies(self._msg_p)
-        return MessageIter(self, msgs_p, db=self._db)
+        return MessageIter(self, msgs_p, db=self._db, msg_cls=OwnedMessage)
 
     def __hash__(self):
         return hash(self.messageid)
@@ -371,14 +371,14 @@ class Message(base.NotmuchObject):
         thread.  Otherwise it will yield no results.
 
-        :returns: An iterator yielding :class:`Message` instances.
+        :returns: An iterator yielding :class:`OwnedMessage` instances.
         :rtype: MessageIter
         """
-- 
2.34.1

_______________________________________________
notmuch mailing list -- notmuch@notmuchmail.org
To unsubscribe send an email to notmuch-le...@notmuchmail.org

Reply via email to